==> crm-commom-vo-1.1.7.1.release.jar: com/biz/crm/nebular/sfa/visitnote/resp/SfaVisitclientRelRespVo.java <==
package com.biz.crm.nebular.sfa.visitnote.resp;

import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 线路组对应客户信息 返回vo
 *
 * @author liuhongming
 * @date 2020-09-18 16:53:00
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "线路组对应客户信息 ")
@SaturnEntity(name = "SfaVisitclientRelRespVo", description = "线路组对应客户信息 ")
public class SfaVisitclientRelRespVo extends CrmExtVo {
    @ApiModelProperty("客户id 客户id")
    @SaturnColumn(description = "客户id 客户id")
    private String clientId;

    @ApiModelProperty("客户编码 客户编码")
    @SaturnColumn(description = "客户编码 客户编码")
    private String clientCode;

    @ApiModelProperty("客户名称 客户名称")
    @SaturnColumn(description = "客户名称 客户名称")
    private String clientName;

    @ApiModelProperty("客户类型 客户类型")
    @SaturnColumn(description = "客户类型 客户类型")
    private String clientType;

    @ApiModelProperty("客户类型描述 客户类型描述 ")
    @SaturnColumn(description = "客户类型描述 客户类型描述")
    private String clientTypeDesc;

    @ApiModelProperty("客户地址 客户地址 ")
    @SaturnColumn(description = "客户地址 客户地址")
    private String clientAddress;

    @ApiModelProperty("网点联系人 网点联系人 ")
    @SaturnColumn(description = "网点联系人 网点联系人")
    private String clientContacts;

    @ApiModelProperty("网点联系电话 网点联系电话 ")
    @SaturnColumn(description = "网点联系电话 网点联系电话")
    private String clientPhone;

    @ApiModelProperty("网点图片 网点图片 ")
    @SaturnColumn(description = "网点图片 网点图片")
    private String clientPhoto;


    @ApiModelProperty("线路组编码 线路组编码")
    @SaturnColumn(description = "线路组编码 线路组编码")
    private String groupCode;

}

==> crm-commom-vo-1.4.0.5.release.jar: com/biz/crm/nebular/sfa/visitnote/resp/SfaVisitclientRelRespVo.java <==
package com.biz.crm.nebular.sfa.visitnote.resp;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 线路组对应客户信息 返回vo
 *
 * @author liuhongming
 * @date 2020-09-18 16:53:00
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "线路组对应客户信息 ")
@SaturnEntity(name = "SfaVisitclientRelRespVo", description = "线路组对应客户信息 ")
public class SfaVisitclientRelRespVo extends CrmExtVo {
    @ApiModelProperty("客户id 客户id")
    @SaturnColumn(description = "客户id 客户id")
    private String clientId;

    @ApiModelProperty("客户编码 客户编码")
    @SaturnColumn(description = "客户编码 客户编码")
    private String clientCode;

    @ApiModelProperty("客户名称 客户名称")
    @SaturnColumn(description = "客户名称 客户名称")
    private String clientName;

    @ApiModelProperty("客户类型 客户类型")
    @SaturnColumn(description = "客户类型 客户类型")
    private String clientType;

    @ApiModelProperty("客户类型描述 客户类型描述 ")
    @CrmDict(typeCode = "sfacusType",dictCodeField = "clientType")
    private String clientTypeDesc;

    @ApiModelProperty("客户地址 客户地址 ")
    @SaturnColumn(description = "客户地址 客户地址")
    private String clientAddress;

    @ApiModelProperty("网点联系人 网点联系人 ")
    @SaturnColumn(description = "网点联系人 网点联系人")
    private String clientContacts;

    @ApiModelProperty("网点联系电话 网点联系电话 ")
    @SaturnColumn(description = "网点联系电话 网点联系电话")
    private String clientPhone;

    @ApiModelProperty("网点图片 网点图片 ")
    @SaturnColumn(description = "网点图片 网点图片")
    private String clientPhoto;


    @ApiModelProperty("线路组编码 线路组编码")
    @SaturnColumn(description = "线路组编码 线路组编码")
    private String groupCode;

}
